pub struct F48Dot16(/* private fields */);Expand description
64-bit signed fixed point number with 16 bits of fraction.
Implementations
Sourceimpl F48Dot16
impl F48Dot16
Sourcepub const fn from_bits(bits: i64) -> Self
pub const fn from_bits(bits: i64) -> Self
Creates a new fixed point value from the underlying bit representation.
Sourcepub fn wrapping_add(self, other: Self) -> Self
pub fn wrapping_add(self, other: Self) -> Self
Wrapping addition.
Sourcepub const fn saturating_add(self, other: Self) -> Self
pub const fn saturating_add(self, other: Self) -> Self
Saturating addition.
Sourcepub fn checked_add(self, other: Self) -> Option<Self>
pub fn checked_add(self, other: Self) -> Option<Self>
Checked addition.
Sourcepub const fn wrapping_sub(self, other: Self) -> Self
pub const fn wrapping_sub(self, other: Self) -> Self
Wrapping substitution.
Sourcepub const fn saturating_sub(self, other: Self) -> Self
pub const fn saturating_sub(self, other: Self) -> Self
Saturating substitution.
Sourcepub const fn to_be_bytes(self) -> [u8; 8]
pub const fn to_be_bytes(self) -> [u8; 8]
The representation of this number as a big-endian byte array.
Sourceimpl F48Dot16
impl F48Dot16
Sourcepub const fn to_i64(self) -> i64
pub const fn to_i64(self) -> i64
Converts a 48.16 fixed point value to a 64 bit integer, rounding off the fractional bits.
Sourcepub const fn to_i32(self) -> i32
pub const fn to_i32(self) -> i32
Converts a 48.16 fixed point value to a 32 bit integer, rounding off the fractional bits.
This truncates the integral bits if the value is too large to fit.