#[repr(C)]pub struct Matrix<T> {
pub xx: T,
pub yx: T,
pub xy: T,
pub yy: T,
pub dx: T,
pub dy: T,
}Expand description
A transformation matrix.
This is a column-major 3x2 affine matrix with the following representation:
| xx xy dx |
| yx yy dy |with the basis vectors (xx, yx), (xy, yy) and the translation
(dx, dy).
Transformation of the point (x, y) is applied as follows:
x' = xx * x + xy * y + dx
y' = yx * x + yy * y + dyOur matrices are typically considered to be right-handed, meaning that positive angles apply counter-clockwise rotations and the rotation matrix for angle a is:
| cos(a) -sin(a) 0 |
| sin(a) cos(a) 0 |Matrix multiplication chains transforms in right to left order meaning
that for C = A * B, matrix C will apply B and then A.
Fields
xx: Tyx: Txy: Tyy: Tdx: Tdy: TImplementations